#!/usr/bin/env python3
# coding: utf-8
import gi
gi.require_version("Gtk", "3.0")
from gi.repository import Gtk, GdkPixbuf
from gi.repository import Notify

from matplotlib.figure import Figure
from matplotlib.backends.backend_gtk3cairo import FigureCanvasGTK3Cairo as FigureCanvas
from matplotlib.backends.backend_gtk3 import NavigationToolbar2GTK3 as NavigationToolbar



water = [0]
increment = [250]


class StackWindow(Gtk.Window):
    def __init__(self):
        Gtk.Window.__init__(self, title ="WaterReminderApp")
        self.set_border_width(10)
        self.set_default_size(400, 800)
        Notify.init("Water Reminder app")

        def stat_fig_generator():
            #la fonction devra prendre deux arguments de type date: debut et fin

            fig = Figure(figsize=(5,5), dpi=80)
            ax = fig.add_subplot(111)
            #Ceci un exemple de statisiques
            # il faudra extraire les données du fichier stats.csv
            # et remplir les listes x et y
            x = [1,2,3,4,5,6,7]
            y = [0.8, 1.2, 1, 0.2, 0.75, 0.5, 1.2]

            #le titre devra s'adapter à la période
            xy = ax.plot(x, y, 'bo-', label='Consommation des 7 derniers jours')

            # à faire adapter l'echelle aux données stats
            ax.set_xlim(1,7)
            ax.set_ylim(0,2)


            ax.legend(loc='upper left')

            ax = fig.gca()

            ax.xaxis.set_ticks_position('bottom')

            ax.yaxis.set_ticks_position('left')


            fig.tight_layout()

            return FigureCanvas(fig)

        def config(widget, entry):
            increment[0] = int(entry.get_text())

        def add_water(widget):
            # Use GdkPixbuf to create the proper image type

            quantity = increment[0]
            water[0] += quantity/1000
            txt = '{0:.3F}L'.format(water[0])
            widget.set_label(txt)

            print('water {0:.3F} L'.format(water[0]))

            n = Notify.Notification.new("GTK3 WaterReminderApp", "{} ML d'eau, bien s'hydrater c'est important".format(quantity))

            if water[0] < 0.5 :

                widget.set_image(img1)

            elif water[0] < 0.75 :

                widget.set_image(img2)

            elif water[0] < 1 :

                widget.set_image(img3)

            elif water[0] < 1.25:

                widget.set_image(img4)

            else:
                widget.set_label('Bravo objectif atteint')
                n.set_title("GTK3 WaterReminderApp", "Objectif atteint Bravo !".format(quantity))

            image = GdkPixbuf.Pixbuf.new_from_file("./images/ampoule.png")

            # Use the GdkPixbuf image
            n.set_image_from_pixbuf(image)
            n.show()
        # Creating a box vertically oriented with a space of 100 pixel.
        vbox = Gtk.Box(orientation = Gtk.Orientation.VERTICAL, spacing = 100)
        #preparation d'une barre header pour recevoir le stack_switcher
        hb = Gtk.HeaderBar()
        hb.set_show_close_button(False)
        vbox.add(hb)
        self.add(vbox)

        # Creating stack, transition type and transition duration.
        stack = Gtk.Stack()
        stack.set_transition_type(Gtk.StackTransitionType.SLIDE_LEFT_RIGHT)
        stack.set_transition_duration(1000)

        # Chargement des images pour l'animation verre d'eau
        pixbuf0 = GdkPixbuf.Pixbuf.new_from_file_at_scale(filename="./images/verreeau_00.png", width=150, height =150, preserve_aspect_ratio=True)
        img0 = Gtk.Image.new_from_pixbuf(pixbuf0)
        pixbuf1 = GdkPixbuf.Pixbuf.new_from_file_at_scale(filename="./images/verreeau_01.png", width=150, height =150, preserve_aspect_ratio=True)
        img1 = Gtk.Image.new_from_pixbuf(pixbuf1)
        pixbuf2 = GdkPixbuf.Pixbuf.new_from_file_at_scale(filename="./images/verreeau_02.png", width=150, height =150, preserve_aspect_ratio=True)
        img2 = Gtk.Image.new_from_pixbuf(pixbuf2)
        pixbuf3 = GdkPixbuf.Pixbuf.new_from_file_at_scale(filename="./images/verreeau_03.png", width=150, height =150, preserve_aspect_ratio=True)
        img3 = Gtk.Image.new_from_pixbuf(pixbuf3)
        pixbuf4 = GdkPixbuf.Pixbuf.new_from_file_at_scale(filename="./images/verreeau_04.png", width=150, height =150, preserve_aspect_ratio=True)
        img4 = Gtk.Image.new_from_pixbuf(pixbuf4)

        #Solution choissie pour faire un menu stack et stack_switcher
        # Stack ---> contiendra les différents éléments à afficher
        # StackSwitcher --> permet de passer d'un élement du stack à un autre
        # pour l'affichage

        #view stats
        stats = stat_fig_generator()
        box_stats = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
        box_stats.pack_start(stats, True, True, 0)
        toolbar = NavigationToolbar(stats, self)
        box_stats.pack_start(toolbar, False, True, 0)
        button_stats = Gtk.Button(label='Stats')

        #element verre d'eau
        #Bouton du verre d'eau et son image associée
        button = Gtk.Button(label='Buvez - clickez',image=img0)
        button.set_always_show_image(True)
        button.connect('clicked', add_water)
        button.set_image_position (2)



        # element de configuration verre d'eau 200 Ml par défaut
        entry = Gtk.Entry()
        entry.set_text("250")
        button2 =Gtk.Button(label='Valider')
        button2.connect('clicked', config,entry)
        vbox1 = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=6)
        vbox1.pack_start(entry, True, True,0 )
        vbox1.pack_start(button2, True, True,0 )

        #les différentes entrées dans le stack
        stack.add_titled(button, "Buvez", "Buvez")
        stack.add_titled(box_stats, "stats", "Stats")
        stack.add_titled(vbox1, "Configurer", "Configurer")


        # Implementation of stack switcher.
        stack_switcher = Gtk.StackSwitcher()
        stack_switcher.set_stack(stack)

        #on met le stack_switcher dans la barre de menu
        hb.pack_start(stack_switcher)

        #On met le stack dans la boite d'endessous
        vbox.pack_start(stack, True, True, 0)


win = StackWindow()
win.connect("destroy", Gtk.main_quit)
win.show_all()
Gtk.main()
